# WorkHistorySummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**action_date** | **datetime** |  | 
**topic** | **str** |  | 
**details** | **str** |  | 
**username** | **str** |  | 
**event** | [**AuditEvent**](AuditEvent.md) |  | 
**event_string** | **str** |  | 
**object_reference** | **str** |  | [optional] 
**update_id** | **float** |  | 
**internal_user_identifier** | **str** |  | [optional] 
**internal_user_name** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

